# Code of Conduct

## Our Pledge

We are committed to providing a welcoming and inclusive environment for
everyone, regardless of age, body size, disability, ethnicity, gender identity
and expression, level of experience, nationality, personal appearance, race,
religion, or sexual identity and orientation.

## Our Standards

**Positive behaviors include:**

- Using welcoming and inclusive language
- Being respectful of differing viewpoints and experiences
- Gracefully accepting constructive criticism
- Focusing on what is best for the community
- Showing empathy towards other community members

**Unacceptable behaviors include:**

- Harassment of any kind
- Discriminatory language or actions
- Personal attacks or insults
- Trolling, spamming, or disruptive behavior
- Publishing others' private information without permission

## Our Responsibilities

Community leaders are responsible for clarifying standards of acceptable
behavior and will take appropriate action in response to unacceptable behavior.

## Scope

This Code of Conduct applies to all community spaces, including:

- GitHub repositories and issues
- Discord channels
- Community forums
- Social media interactions
- In-person events

## Enforcement

Instances of abusive, harassing, or otherwise unacceptable behavior may be
reported to the community leaders responsible for enforcement. All complaints
will be reviewed and investigated promptly and fairly.

Community leaders have the right and responsibility to remove, edit, or reject
comments, commits, code, wiki edits, issues, and other contributions that are
not aligned with this Code of Conduct.

## Attribution

This Code of Conduct is adapted from the
[Contributor Covenant](https://www.contributor-covenant.org/), version 2.1.

For answers to common questions about this code of conduct, see the FAQ at
https://www.contributor-covenant.org/faq.
